about summary refs log tree commit diff
path: root/sysdeps/ieee754/ldbl-96/test-totalorderl-ldbl-96.c
diff options
context:
space:
mode:
Diffstat (limited to 'sysdeps/ieee754/ldbl-96/test-totalorderl-ldbl-96.c')
-rw-r--r--sysdeps/ieee754/ldbl-96/test-totalorderl-ldbl-96.c13
1 files changed, 12 insertions, 1 deletions
diff --git a/sysdeps/ieee754/ldbl-96/test-totalorderl-ldbl-96.c b/sysdeps/ieee754/ldbl-96/test-totalorderl-ldbl-96.c
index 07fa772414..6afc1b5c1b 100644
--- a/sysdeps/ieee754/ldbl-96/test-totalorderl-ldbl-96.c
+++ b/sysdeps/ieee754/ldbl-96/test-totalorderl-ldbl-96.c
@@ -1,4 +1,4 @@
 /* Test totalorderl for ldbl-96.
    Copyright (C) 2016 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
@@ -62,6 +62,17 @@ do_test (void)
 	    printf ("FAIL: test %zu\n", i);
 	    result = 1;
 	  }
+	to1 = totalordermagl (ldx, ldy);
+	to2 = totalordermagl (ldy, ldx);
+	to3 = totalordermagl (ldnx, ldny);
+	to4 = totalordermagl (ldny, ldnx);
+	if (to1 && to2 && to3 && to4)
+	  printf ("PASS: test %zu (totalordermagl)\n", i);
+	else
+	  {
+	    printf ("FAIL: test %zu (totalordermagl)\n", i);
+	    result = 1;
+	  }
       }
 
   return result;
@@ -1,4 +1,4 @@
-/* Test totalorderl for ldbl-96.
+/* Test totalorderl and totalordermagl for ldbl-96.
    Copyright (C) 2016 Free Software Foundation, Inc.
    This file is part of the GNU C Library.